@@ -1,7 +1,7 @@
 package RDF::Helper;
 use 5.10.1;
 use Moose;
-our $VERSION = '1.99_01';
+our $VERSION = '1.99_02';
 
 use RDF::Helper::Statement;
 use RDF::Helper::Object;
@@ -49,7 +49,7 @@ RDF::Helper - Provide a consistent, high-level API for working with RDF with Per
 
   my $rdf = RDF::Helper->new(
       BaseInterface => 'RDF::Trine',
-      Namespaces => {
+      namespaces => {
           dct => 'http://purl.org/dc/terms/',
           rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
          '#default' => "http://purl.org/rss/1.0/",
@@ -73,7 +73,7 @@ which is closer to RDF.
 
   my $rdf = RDF::Helper->new(
       BaseInterface => 'RDF::Trine',
-      Namespaces => {
+      namespaces => {
           dc => 'http://purl.org/dc/terms/',
           rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
          '#default' => "http://purl.org/rss/1.0/",
@@ -98,9 +98,9 @@ used (L<RDF::Trine::Model> for a BaseInterface of L<RDF::Trine>,
 etc.). If this option is omitted, a new, in-memory model will be
 created.
 
-=head2 Namespaces
+=head2 namespaces
 
-The C<Namespaces> option expects a hash reference of prefix/value
+The C<namespaces> option expects a hash reference of prefix/value
 pairs for the namespaces that will be used with this instance of the
 Helper. The special '#default' prefix is reserved for setting the
 default namespace.
@@ -114,7 +114,7 @@ common grammars:
 
   my $rdf = RDF::Helper->new(
       BaseInterface => 'RDF::Trine',
-      Namespaces => {
+      namespaces => {
           rdf => RDF_NS,
           rss => RSS1_NS,
           foaf => FOAF_NS
@@ -127,7 +127,7 @@ common grammars:
 Setting a non-zero value for the C<ExpandQNames> option configures the
 current instance of the Helper to allow for qualified URIs to be used
 in the arguments to many of the Helper's convenience methods. For
-example, given the L<Namespaces> option for the previous example, with
+example, given the L<namespaces> option for the previous example, with
 C<ExpandQNames> turned on, the following will work as expected.
 
   $rdf->assert_resource( $uri, 'rdf:type', 'foaf:Person' );
@@ -337,12 +337,12 @@ current model.
 
 This method will import the RDF statements contained in an RDF/XML
 document, either from a file or a string, into the current RDF model.
-If a L</BaseURI> was specified in the L<RDF::Helper>
+If a L</base_uri> was specified in the L<RDF::Helper>
 L<constructor|/"CONSTRUCTOR OPTIONS">, then that URI is used as the
 base for when the supplied RDF/XML is imported.  For instance, if the
 hash notation is used to reference an RDF node
 (e.g. C<E<lt>rdf:Description rdf:about="#dahut"/E<gt>>), the
-L</BaseURI> will be prepended to the C<rdf:about> URI.
+L</base_uri> will be prepended to the C<rdf:about> URI.
 
 =head2 serialize
 
@@ -359,21 +359,12 @@ types:
 
 =over 4
 
-=item *
-
-rdfxml
-
-=item *
-
-rdfxml-abbrev
-
-=item *
-
-ntriple
-
-=item *
-
-trix
+=item * ntriples
+=item * nquads
+=item * rdfxml
+=item * rdfjson
+=item * ntriples-canonical
+=item * turtle
 
 =back
 
